@@ -10,11 +10,11 @@ ACL::Lite - Liteweight and flexible ACL checks
 
 =head1 VERSION
 
-Version 0.0002
+Version 0.0003
 
 =cut
 
-our $VERSION = '0.0002';
+our $VERSION = '0.0003';
 
 =head1 SYNOPSIS
 
@@ -32,6 +32,21 @@ our $VERSION = '0.0002';
         print "Permission denied\n";
     }
 
+    $acl = ACL::Lite->new(uid => 666);
+
+    $acl->check('authenticated');
+
+=head1 DESCRIPTION
+
+C<ACL::Lite> is a simple permission checker without any prerequisites.
+
+C<ACL> stands for "Access Control Lists".
+
+=head2 DEFAULT PERMISSION
+
+The default permission depends on whether you pass a C<uid> (authenticated)
+or not (anonymous).
+
 =head1 CONSTRUCTOR
 
 =head2 new
@@ -95,6 +110,14 @@ sub new {
 		}
 	}
 
+    # add default permissions
+    if ($self->{uid}) {
+        $self->{permissions}->{authenticated} = 1;
+    }
+    else {
+        $self->{permissions}->{anonymous} = 1;
+    }
+
 	return $self;
 }
 
